
From: Bill Nottingham <notting@redhat.com>

When allocating a new VC with vgacon_init(), the font is shared across all
the VGA consoles.  However, the font mask was always set to the default
value of zero in visual_init(), even if we were using 512 character fonts
at the time.

Moreover, code in vgacon.c:vga_do_font_op() didn't reset the mask if the
console driver thinks it's already in 512 character mode.  This means that
to *fix* it, you'd actually have to take the console out of 512 character
mode and then set it back.

The attached sets vc_hi_font_mask in vgacon_init() for any new consoles
opened if the vgacon driver is already in 512 character mode, solving this.

This bug goes back to 2.4.18 at least, probably earlier.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/video/console/vgacon.c |    2 ++
 1 files changed, 2 insertions(+)

diff -puN drivers/video/console/vgacon.c~vgacon-set-vc_hi_font_mask-correctly drivers/video/console/vgacon.c
--- 25/drivers/video/console/vgacon.c~vgacon-set-vc_hi_font_mask-correctly	2005-03-17 21:45:17.000000000 -0800
+++ 25-akpm/drivers/video/console/vgacon.c	2005-04-25 18:46:00.459430232 -0700
@@ -337,6 +337,8 @@ static void vgacon_init(struct vc_data *
 	c->vc_scan_lines = vga_scan_lines;
 	c->vc_font.height = vga_video_font_height;
 	c->vc_complement_mask = 0x7700;
+	if (vga_512_chars)
+		c->vc_hi_font_mask = 0x0800;
 	p = *c->vc_uni_pagedir_loc;
 	if (c->vc_uni_pagedir_loc == &c->vc_uni_pagedir ||
 	    !--c->vc_uni_pagedir_loc[1])
_
